pyhsm.aes_ecb_cmd

Package pyhsm :: Module aes_ecb_cmd |
[frames] | no frames]

# Module aes_ecb_cmd

implementations of AES ECB block cipher commands to execute on a YubiHSM

Classes
| YHSM_Cmd_AES_ECB_Encrypt Have the YubiHSM AES ECB encrypt something using the key of a key handle.
| YHSM_Cmd_AES_ECB_Decrypt Have the YubiHSM AES ECB decrypt something using the key of a key handle.
| YHSM_Cmd_AES_ECB_Compare Have the YubiHSM AES ECB decrypt something using the key of a key handle, and then compare it with a plaintext we supply.